/**
 * @fileoverview The Components Library contains the HP developed library code for use
 * in the SMH Web App pages (for Windows).
 * 
 * @author Scott Felt
 * @author Shashi Dande
 * @author Sridhar Krishnan
 * @author Senthil Raju
 *
 * @version 1.0
 */

 
 /**
  * Create a large-sized masthead
	* @param {string} imgLogo A string representing the name and path of the HP masthead image
	* @param {string} title Title that will appear in the masthead
	* @param {string} picMasthead A string representing the name and path of the picture that will appear on the masthead
	* @param {string} helpurl Path to help page
	*/
 function Largemasthead(imgLogo,title,picMasthead,helpurl)
 {
	document.write('<table border="0" cellpadding="0" cellspacing="0" width="100%" class="applicationMastheadLarge">');
	document.write('<tr>');
	document.write('<td class="mastheadIcon" width="42"><img src='+imgLogo+' width="42" height="26" border="0" alt="HP"></td>');
	document.write('<td class="mastheadTitle">');
	document.write('<h1>'+title+'</h1></td>');
	document.write('<td width="307"><div class="mastheadPhoto" style="padding-right:0px;"><img src="'+picMasthead+'" width="307" height="57" border="0" alt=""></div></td>');
	document.write('<td class="mastheadLinks" style="padding:5px 16px;"><br><br>');
	document.write('<a href="'+helpurl+'" target="helpwindow">Help</a>');
	document.write('</td>');
	document.write('</tr>');
	document.write('</table>');
}

 /**
  * Create a small-sized masthead
	* @param {string} imgLogo A string representing the name and path of the HP masthead image
	* @param {string} title Title that will appear in the masthead
	* @param {string} picMasthead A string representing the name and path of the picture that will appear on the masthead
	* @param {string} helpurl Path to help page
	*/
function Smallmasthead(imgLogo,title,picMasthead,helpurl)
{
	document.write('<table border="0" cellpadding="0" cellspacing="0" width="100%" class="applicationMastheadSmall">');
	document.write('<tr>');
	document.write('<td class="mastheadIcon" width="30"><img src='+imgLogo+' width="30" height="19" border="0" alt="HP"></td>');
	document.write('<td class="mastheadTitle"><h1>'+title+'</h1></td>');
	document.write('<td width="307"><div class="mastheadPhoto"><img src="'+picMasthead+'" width="307" height="39" border="0" alt=""></div></td>');
	document.write('<td class="mastheadLinks" style="padding:5px 16px;"><br>');
	document.write('<a href="'+helpurl+'" target="helpwindow">Help</a>');
	document.write('</td>');
	document.write('</tr>');
	document.write('</table>');
}

/**
 * Create a small-sized masthead with no help link
 * @param {string} imgLogo A string representing the name and path of the HP masthead image
 * @param {string} title Title that will appear in the masthead
 * @param {string} picMasthead A string representing the name and path of the picture that will appear on the masthead
 */
function SmallmastheadNoHelp(imlLogo, title, picMasthead)
{
	document.write('<table border="0" cellpadding="0" cellspacing="0" width="100%" class="applicationMastheadSmall">');
	document.write('<tr>');
	document.write('<td class="mastheadIcon" width="30"><img src='+imgLogo+' width="30" height="19" border="0" alt="HP"></td>');
	document.write('<td class="mastheadTitle"><h1>'+title+'</h1></td>');
	document.write('<td width="307"><div class="mastheadPhoto"><img src="'+picMasthead+'" width="307" height="39" border="0" alt=""></div></td>');
//	document.write('<td class="mastheadLinks" style="padding:5px 16px;"><br>');
//	document.write('</td>');
	document.write('</tr>');
	document.write('</table>');
}



/* List Control Library code */	

function unorderStart()
{
	document.write('<ul>');
}
function unorderEnd()
{
	document.write('</ul>');
}
function list(listArray)
{
	for(i =0; i<listArray.length; i++)
	document.write('<li>'+listArray[i]+'</li>');
}
function orderStart()
{
	document.write('<ol>');
}
function orderEnd()
{
	document.write('</ol>');
}
function simplelist()
{
	document.write('<li>');
}
function listEnd()
{
	document.write('</li>');
}

/* Tree Control Library code */	

function TreeOpenCloseStart(divclass)
{
	 document.write('<div class="'+divclass+'">');
	 document.write ('<div class="treeControl"><div class="treeDisclosure"></div></div>');
}

function TreeOpenCloseEnd(divclass)
{
	document.write('</div>');
}

function TreeTitleStart(titleClass,aClass,link,target,title)
{
	 document.write('<div class="'+titleClass+'"><A class='+aClass+' href="'+link+'" target="'+target+'">'+title+'</A></div>');
}

function TreeTitleEnd()
{
	document.write('</div>');
}

function TreeContentStart(divClass)
{
	document.write('<div class="'+divClass+'">');
}

function TreeContentEnd()
{
	document.write('</div>');
}

function TreeLeaf(wrapperClass,leafClass,aClass,link,target,leafTitle)
{
	document.write('<div class="'+wrapperClass+'">');
	document.write('<div class="'+leafClass+'">');
	document.write('<A class="'+aClass+'" href="'+link+'" target="'+target+'">'+leafTitle+'</A>');
	document.write('</div>');
	document.write('</div>');
}

/**
 * Displays an Operational Status icon based on parameter passed
 * @param {string} numericStatus The numerical value of the OperationalStatus (given as a 
 *                               JavaScript string).
 */
function getGroupOperationalStatusIcon(numericStatus)
{
  switch(String(numericStatus))
	{
	  case "0":
		  document.write('<img src="/images/unknown_20.gif" alt="Unknown"></img>');
			break;
		case "1":
		  document.write('<img src="/images/info_20.gif" alt="Informational"></img>');
			break;
		case "2":
		  document.write('<img src="/images/normal_20.gif" alt="Normal"></img>');
			break;
		case "3":
		  document.write('<img src="/images/minor_20.gif" alt="Degraded"></img>');
			break;
		case "6":
		  document.write('<img src="/images/critical_20.gif" alt="Critical"></img>');
			break;
		default:
		  document.write('<img src="/images/unknown_20.gif" alt="Unknown"></img>');
			break;
	}
}

function  getGroupOperationalStatusSmallIcon(numericStatus)
{
  switch(String(numericStatus))
	{
	  case "0":
		  document.write('<img src="/images/icon_status_unknown.gif" alt="Unknown"></img>');
			break;
		case "1":
		  document.write('<img src="/images/icon_status_informational.gif" alt="Informational"></img>');
			break;
		case "2":
		  document.write('<img src="/images/icon_status_normal.gif" alt="Normal"></img>');
			break;
		case "3":
		  document.write('<img src="/images/icon_status_minor.gif" alt="Degraded"></img>');
			break;
		case "6":
		  document.write('<img src="/images/icon_status_critical.gif" alt="Critical"></img>');
			break;
		default:
		  document.write('<img src="/images/icon_status_unknown.gif" alt="Unknown"></img>');
			break;
	}
}

/**
 * Get the HTML Tag for Operational Status icon based on parameter passed
 * @param {string} numericStatus The numerical value of the OperationalStatus (given as a 
 *                               JavaScript string).
 */
function getGroupOperationalStatusIconTag(numericStatus, text)
{
  var outString;
  switch(String(numericStatus))
	{
	  case "0":
		  outString = '<img src="/images/icon_status_unknown.gif" class="treeIdentifierIcon2" alt="Unknown">'+text+'</img>';
			break;
		case "1":
		   outString = '<img src="/images/icon_status_informational.gif" class="treeIdentifierIcon2" alt="Informational">'+text+'</img>';
			break;
		case "2":
		   outString = '<img src="/images/icon_status_normal.gif" class="treeIdentifierIcon2" alt="Normal">'+text+'</img>';
			break;
		case "3":
		   outString = '<img src="/images/icon_status_minor.gif" class="treeIdentifierIcon2" alt="Degraded">'+text+'</img>';
			break;
		case "6":
		   outString = '<img src="/images/icon_status_critical.gif" class="treeIdentifierIcon2" alt="Critical">'+text+'</img>';
			break;
		default:
		   outString = '<img src="/images/icon_status_unknown.gif" class="treeIdentifierIcon2" alt="Unknown">'+text+'</img>';
			break;
	}

	return outString;
}

/**
 * Displays an Redundancy Status icon based on parameter passed
 * @param {string} numericStatus The numerical value of the RedundacyStatus (given as a 
 *                               JavaScript string).
 */
function getRendundancyStatusIcon(numericStatus)
{
  switch(String(numericStatus))
	{
	  case "0":
		  document.write('<img src="/images/unknown_20.gif" alt="Unknown"></img>');
			break;
		case "1":
		  document.write('<img src="/images/info_20.gif" alt="Other"></img>');
			break;
		case "2":
		  document.write('<img src="/images/normal_20.gif" alt="Redundant/OK"></img>');
			break;
		case "3":
		  document.write('<img src="/images/minor_20.gif" alt="Degraded"></img>');
			break;
		case "4":
		  document.write('<img src="/images/major_20.gif" alt="Redundancy Lost"></img>');
			break;
		case "5":
		  document.write('<img src="/images/critical_20.gif" alt="Overall Failure"></img>');
			break;
		default:
		  document.write('<img src="/images/unknown_20.gif" alt="Unknown"></img>');
			break;
	}
}

function getRendundancyStatusSmallIcon(status)
{
  var arrImageStrings = new Array();
  switch(String(status))
	{
		case "0":
		  document.write('<img src="/images/icon_status_unknown.gif" alt="Unknown"></img>');
			break;
		case "1":
		  document.write('<img src="/images/icon_status_informational.gif" alt="Other"></img>');
			break;
		case "2":
		  document.write('<img src="/images/icon_status_normal.gif" alt="Redundant/OK"></img>');
			break;
		case "3":
		  document.write('<img src="/images/icon_status_minor.gif" alt="Degraded"></img>');
			break;
		case "4":
		  document.write('<img src="/images/icon_status_major.gif" alt="Redundancy Lost"></img>');
			break;
		case "5":
		  document.write('<img src="/images/icon_status_critical.gif" alt="Overall Failure"></img>');
			break;
		default:
		  document.write('<img src="/images/icon_status_unknown.gif" alt="Unknown"></img>');
			break;
	}
}


/**
 * Displays an Operational Status icon and text in an <H3> tag based on parameters passed
 * @param {string} numericStatus The numerical value of the OperationalStatus (given as a 
 *                               JavaScript string).
 * @param {string} text The text that will be displayed next to the status icon.
 */
function getGroupOperationalStatusIconH3(numericStatus, text)
{
  switch(String(numericStatus))
	{
	  case "0":
		  document.write('<h3><img src="/images/unknown_20.gif" alt="Unknown"></img>'+text+'</h3>');
			break;
		case "1":
		  document.write('<h3><img src="/images/info_20.gif" alt="Informational"></img>'+text+'</h3>');
			break;
		case "2":
		  document.write('<h3><img src="/images/normal_20.gif" alt="Normal"></img>'+text+'</h3>');
			break;
		case "3":
		  document.write('<h3><img src="/images/minor_20.gif" alt="Degraded"></img>'+text+'</h3>');
			break;
		case "6":
		  document.write('<h3><img src="/images/critical_20.gif" alt="Critical"></img>'+text+'</h3>');
			break;
		default:
		  document.write('<h3><img src="/images/unknown_20.gif" alt="Unknown"></img>'+text+'</h3>');
			break;
	}
}

/**
 * Displays an Redundancy Status icon and text in an <H3> tag based on parameters passed
 * @param {string} numericStatus The numerical value of the RedundancyStatus (given as a 
 *                               JavaScript string).
 * @param {string} text The text that will be displayed next to the status icon.
 */
function getRendundancyStatusIconH3(numericStatus, text)
{
  switch(String(numericStatus))
	{
	  case "0":
		  document.write('<h3><img src="/images/unknown_20.gif" alt="Unknown"></img>'+text+'</h3>');
			break;
		case "1":
		  document.write('<h3><img src="/images/info_20.gif" alt="Other"></img>'+text+'</h3>');
			break;
		case "2":
		  document.write('<h3><img src="/images/normal_20.gif" alt="Redundant/OK"></img>'+text+'</h3>');
			break;
		case "3":
		  document.write('<h3><img src="/images/minor_20.gif" alt="Degraded"></img>'+text+'</h3>');
			break;
		case "4":
		  document.write('<h3><img src="/images/major_20.gif" alt="Redundancy Lost"></img>'+text+'</h3>');
			break;
		case "5":
		  document.write('<h3><img src="/images/critical_20.gif" alt="Overall Failure"></img>'+text+'</h3>');
			break;
		default:
		  document.write('<h3><img src="/images/unknown_20.gif" alt="Unknown"></img>'+text+'</h3>');
			break;
	}
}

/**
 * Creates the framework of an HTML table using DOM calls; the column
 * widths are set by the browser.  
 * @param {string} id The name of the table.
 * @param {string[]} arrHeadings Array of headings for the table.
 */
function createTable(id, arrHeadings)
{
  var mybody = document.getElementsByTagName("body")[0];
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
		
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		//mycurrent_row.setAttribute("className","captionRow");
		var i;
		for (i=0; i<arrHeadings.length; i++)
		{
  		// create heading
    	mycurrent_cell = document.createElement("th");
    	currenttext = document.createTextNode(arrHeadings[i]);
    	mycurrent_cell.appendChild(currenttext);
    	mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
}

/**
 * Creates the framework of an HTML table using DOM calls; 
 * The table has no Headings.
 * @param {string} id The name of the table.
 */
function createTable5(id, tagId)
{
  //var mybody = document.getElementsByTagName("body")[0];
  var mybody = document.getElementById(tagId);
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
	
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		
			mycolgroup = document.createElement("colgroup");
			//mytable.appendChild(mycolgroup);
			mycol = document.createElement("col");
			w = "100%";
			mycol.width = w;
			mycolgroup.appendChild(mycol);
		mytable.appendChild(mycolgroup);
		
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","1");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
		
		//mytable.appendChild(mycolgroup);
}

/**
 * Creates the framework of an HTML table using DOM calls; the column
 * widths are set by the browser.  
 * @param {string} id The name of the table.
 * @param {string} tagId The id of the DOM element that the table will be appended to
 * @param {string[]} arrHeadings Array of headings for the table.
 */
function createTable4(id, tagId, arrHeadings)
{
  //var mybody = document.getElementsByTagName("body")[0];
  var mybody = document.getElementById(tagId);
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
		
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		//mycurrent_row.setAttribute("className","captionRow");
		var i;
		for (i=0; i<arrHeadings.length; i++)
		{
  		// create heading
    	mycurrent_cell = document.createElement("th");
    	currenttext = document.createTextNode(arrHeadings[i]);
    	mycurrent_cell.appendChild(currenttext);
    	mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
}

/**
 * Gets the details needed to display one of the redundancy images.
 * @param {string} status The numerical value of the redundancy status (given as a 
 *                        JavaScript string).
 * @return {string[]} arrImageStrings Array where first element is the
 *                                    string representing the path to the
 *                                    image and the second element is the
 *                                    alt string.
 */
function getRedundancyImagePath(status)
{
  var arrImageStrings = new Array();
  switch(String(status))
	{
	  case "0":
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
		case "1":
		  arrImageStrings[0] = "/images/icon_status_informational.gif";
			arrImageStrings[1] = "Informational";
			return arrImageStrings;
			break;
		case "2":
		  arrImageStrings[0] = "/images/icon_status_normal.gif";
			arrImageStrings[1] = "Redundant/OK";
			return arrImageStrings;
			break;
		case "3":
		  arrImageStrings[0] = "/images/icon_status_minor.gif";
			arrImageStrings[1] = "Degraded";
			return arrImageStrings;
			break;
		case "4":
		  arrImageStrings[0] = "/images/icon_status_major.gif";
			arrImageStrings[1] = "Redundancy Lost";
		  return arrImageStrings;
			break;
		case "5":
		  arrImageStrings[0] = "/images/icon_status_critical.gif";
			arrImageStrings[1] = "Overall Failure";
		  return arrImageStrings;
			break;
		default:
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
	}
}

/**
 * Gets the details needed to display one of the operational status images.
 * @param {string} status The numerical value of the status (given as a 
 *                        JavaScript string).
 * @return {string[]} arrImageStrings Array where first element is the
 *                                    string representing the path to the
 *                                    image and the second element is the
 *                                    alt string.
 */
function getOpstatImagePath(status)
{
  var arrImageStrings = new Array();
  switch(String(status))
	{
	  case "0":
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
		case "1":
		  arrImageStrings[0] = "/images/icon_status_informational.gif";
			arrImageStrings[1] = "Informational";
			return arrImageStrings;
			break;
		case "2":
		  arrImageStrings[0] = "/images/icon_status_normal.gif";
			arrImageStrings[1] = "Redundant/OK";
			return arrImageStrings;
			break;
		case "3":
		  arrImageStrings[0] = "/images/icon_status_minor.gif";
			arrImageStrings[1] = "Degraded";
			return arrImageStrings;
			break;
        case "5":
		  arrImageStrings[0] = "/images/icon_status_major.gif";
			arrImageStrings[1] = "Predictive Failure";
		  return arrImageStrings;
			break;
		case "6":
		  arrImageStrings[0] = "/images/icon_status_critical.gif";
			arrImageStrings[1] = "Critical";
		  return arrImageStrings;
			break;
		default:
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
	}
}

/**
 * Gets the details needed to display one of the operational status images.
 * @param {string} status The numerical value of the status (given as a 
 *                        JavaScript string).
 * @return {string[]} arrImageStrings Array where first element is the
 *                                    string representing the path to the
 *                                    image and the second element is the
 *                                    alt string.
 */
function getStateImagePathForIndication(status)
{
  var arrImageStrings = new Array();
  switch(String(status))
	{
	  case "0":
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
		case "1":
		  arrImageStrings[0] = "/images/normal_20.gif";
			arrImageStrings[1] = "Normal";
			return arrImageStrings;
			break;
		case "2":
		  arrImageStrings[0] = "/images/info_20.gif";
			arrImageStrings[1] = "Informational";
			return arrImageStrings;
			break;
		case "3":
		  arrImageStrings[0] = "/images/warning_20.gif";
			arrImageStrings[1] = "Warning";
			return arrImageStrings;
			break;
		case "4":
			arrImageStrings[0] = "/images/minor_20.gif";
			arrImageStrings[1] = "Minor";
			return arrImageStrings;
			break;
        case "5":
		  arrImageStrings[0] = "/images/major_20.gif";
			arrImageStrings[1] = "Major";
		  return arrImageStrings;
			break;
		case "6":
		  arrImageStrings[0] = "/images/critical_20.gif";
			arrImageStrings[1] = "Critical";
		  return arrImageStrings;
			break;
		default:
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
	}
}

/**
 * Gets the details needed to display one of the Group operational status images.
 * @param {string} status The numerical value of the status (given as a 
 *                        JavaScript string).
 * @return {string[]} arrImageStrings Array where first element is the
 *                                    string representing the path to the
 *                                    image and the second element is the
 *                                    alt string.
 */
function getGroupOpStatImagePath(status)
{

  var arrImageStrings = new Array();
  switch(String(status))
	{
	  case "0":
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
		case "1":
		  arrImageStrings[0] = "/images/icon_status_informational.gif";
			arrImageStrings[1] = "Informational";
			return arrImageStrings;
			break;
		case "2":
		  arrImageStrings[0] = "/images/icon_status_normal.gif";
			arrImageStrings[1] = "Redundant/OK";
			return arrImageStrings;
			break;
		case "3":
		  arrImageStrings[0] = "/images/icon_status_minor.gif";
			arrImageStrings[1] = "Degraded";
			return arrImageStrings;
			break;
		case "6":
		  arrImageStrings[0] = "/images/icon_status_critical.gif";
			arrImageStrings[1] = "Overall Failure";
		  return arrImageStrings;
			break;
		default:
		  arrImageStrings[0] = "/images/icon_status_unknown.gif";
			arrImageStrings[1] = "Unknown";
		  return arrImageStrings;
			break;
	}
}

/**
 * Creates a single-row table that serves as a title bar, including
 * and image representing status.
 * @param {string} id The name of the table
 * @param {string} status Value to be used to get correct image
 * @param {string} imageType Only valid strings are "redundancy" or "opstat"
 * @param {string} title The title of the table
 */
function createTableWithStatusImage(id, status, imageType, title)
{

  var mybody = document.getElementsByTagName("body")[0];
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
		
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		//mycurrent_row.setAttribute("className","captionRow");
		var img = document.createElement("img");
		var arrTmp = new Array();
		if (imageType == "redundancy")
		{
		  arrTmp = getRedundancyImagePath(status);
		}
		else if (imageType == "opstat")
		{
		  arrTmp = getOpstatImagePath(status);
		}
		img.src = arrTmp[0];
		img.alt = arrTmp[1];
		cell_1 = document.createElement("th");
		cell_1.appendChild(img);
		titleText = document.createTextNode("  " + title);
		cell_1.appendChild(titleText);
		mycurrent_row.appendChild(cell_1);
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
}

/**
 * Creates a single-row table that serves as a title bar, including
 * and image representing status.
 * @param {string} id The name of the table
 * @param {string} tagId The id of the DOM element that the table will be appended to
 * @param {string} status Value to be used to get correct image
 * @param {string} imageType Only valid strings are "redundancy" or "opstat"
 * @param {string} title The title of the table
 */
function createTableWithStatusImage2(id, tagId, status, imageType, title)
{

  //var mybody = document.getElementsByTagName("body")[0];
  var mybody = document.getElementById(tagId);
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
		
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		//mycurrent_row.setAttribute("className","captionRow");
		var img = document.createElement("img");
		var arrTmp = new Array();
		if (imageType == "redundancy")
		{
		  arrTmp = getRedundancyImagePath(status);
		}
		else if (imageType == "opstat")
		{
		  arrTmp = getOpstatImagePath(status);
		}
		img.src = arrTmp[0];
		img.alt = arrTmp[1];
		cell_1 = document.createElement("th");
		cell_1.appendChild(img);
		titleText = document.createTextNode("  " + title);
		cell_1.appendChild(titleText);
		mycurrent_row.appendChild(cell_1);
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
}



/**
 * Creates the framework of an HTML table using DOM calls; the column
 * widths are specified in the API.  
 * @param {string} id The name of the table.
 * @param {string[]} arrHeadings Array of headings for the table.  Must be same
 *                               length as arrWidths.
 * @param {string[]} arrWidths Array of width values for each column.  Must be same
 *                             length as arrHeadings.
 * @type void
 */
function createTable2(id, arrHeadings, arrWidths)
{
  // validate that arrHeadings and arrWidths are
	// the same length.  If not, call createTable
	// (without any width parameters)

	if (arrHeadings.length != arrWidths.length)
	{
	  createTable(id, arrHeadings);
		return 0;
	}

  var mybody = document.getElementsByTagName("body")[0];
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
	
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		
			mycolgroup = document.createElement("colgroup");
			//mytable.appendChild(mycolgroup);
		for (var i=0; i<arrHeadings.length; i++)
		{	
			mycol = document.createElement("col");
			w = arrWidths[i] + "%";
			mycol.width = w;
			mycolgroup.appendChild(mycol);
		}
		mytable.appendChild(mycolgroup);
		
		for (var i=0; i<arrHeadings.length; i++)
		{
  		// create heading
    	mycurrent_cell = document.createElement("th");
    	currenttext = document.createTextNode(arrHeadings[i]);
    	mycurrent_cell.appendChild(currenttext);
    	mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
		
		//mytable.appendChild(mycolgroup);
}


/**
 * Creates the framework of an HTML table using DOM calls; the column
 * widths are specified in the API.  
 * @param {string} id The name of the table.
 * @param {string[]} arrStatus Array of status values.
 * @param {string[]} arrHeadings Array of headings for the table.  Must be same
 *                               length as arrWidths.
 * @param {string[]} arrWidths Array of width values for each column.  Must be same
 *                             length as arrHeadings.
 * @type void
 */
function createTableSpecialRedundancySets(id, arrStatus, arrHeadings, arrWidths)
{
  // validate that arrHeadings and arrWidths are
	// the same length.  If not, call createTable
	// (without any width parameters)

	if (arrHeadings.length != arrWidths.length)
	{
	  createTable(id, arrHeadings);
		return 0;
	}

  var mybody = document.getElementsByTagName("body")[0];
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
	
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		
			mycolgroup = document.createElement("colgroup");
			//mytable.appendChild(mycolgroup);
		for (var i=0; i<arrHeadings.length; i++)
		{	
			mycol = document.createElement("col");
			w = arrWidths[i] + "%";
			mycol.width = w;
			mycolgroup.appendChild(mycol);
		}
		mytable.appendChild(mycolgroup);
		
		for (var i=0; i<arrHeadings.length; i++)
		{
			// create heading
			if (i > 0)
			{
			   var img = document.createElement("img");
			   var arrTmp = new Array();
			   arrTmp = getRedundancyImagePath(arrStatus[i]);
			   img.src = arrTmp[0];
			   img.alt = arrTmp[1];
			}
			mycurrent_cell = document.createElement("th");
			if (i > 0)
			{
				mycurrent_cell.appendChild(img);
				currenttext = document.createTextNode(" " + arrHeadings[i]);
				mycurrent_cell.appendChild(currenttext);
			}
			else
			{
			   currenttext = document.createTextNode(arrHeadings[i]);
			   mycurrent_cell.appendChild(currenttext);
			}
			mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
		
		//mytable.appendChild(mycolgroup);
}



/**
 * Creates the framework of an HTML table using DOM calls; the column
 * widths are specified in the API.  
 * @param {string} id The name of the table.
 * @param {string} tagId The id of the DOM element that the table will be appended to
 * @param {string[]} arrHeadings Array of headings for the table.  Must be same
 *                               length as arrWidths.
 * @param {string[]} arrWidths Array of width values for each column.  Must be same
 *                             length as arrHeadings.
 * @type void
 */
function createTable3(id, tagId, arrHeadings, arrWidths)
{
  // validate that arrHeadings and arrWidths are
	// the same length.  If not, call createTable
	// (without any width parameters)

	if (arrHeadings.length != arrWidths.length)
	{
	  createTable(id, arrHeadings);
		return 0;
	}

  //var mybody = document.getElementsByTagName("body")[0];
  var mybody = document.getElementById(tagId);
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
	
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		
			mycolgroup = document.createElement("colgroup");
			//mytable.appendChild(mycolgroup);
		for (var i=0; i<arrHeadings.length; i++)
		{	
			mycol = document.createElement("col");
			w = arrWidths[i] + "%";
			mycol.width = w;
			mycolgroup.appendChild(mycol);
		}
		mytable.appendChild(mycolgroup);
		
		for (var i=0; i<arrHeadings.length; i++)
		{
  		// create heading
    	mycurrent_cell = document.createElement("th");
    	currenttext = document.createTextNode(arrHeadings[i]);
    	mycurrent_cell.appendChild(currenttext);
    	mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
		
		//mytable.appendChild(mycolgroup);
}

/**
 * Appends a table row to a table
 * @param {string} id The name of the table to be appended.
 * @param {string[]} arrValues Array of values containing all of the row data.
 */ 
function appendRow(id, arrValues, trId)
{
 var cell;
 if(id=="EmptySlots") {
    return 0;
 }
 var tbody = document.getElementById(id).getElementsByTagName("tbody")[0];
 var row = document.createElement("TR");
 if(trId != null && trId != 'undefined'){
	 row.id = trId;
 }
 var i;
 for (i = 0; i < arrValues.length; i++)
 {
   cell = document.createElement("TD");
	 cell.innerHTML = arrValues[i];
	 row.appendChild(cell);
 }
 tbody.appendChild(row);
}

/**
 * Appends a hidden table row to a table
 * @param {string} id The name of the table to be appended.
 * @param {string} trId should be hidden
 * @param {string} arrValue  containing of the row data.
 * @param {int} numbers of column be merged.
 */ 
function appendHiddenRow(id, trId, divId, mergeNum)
{
	 var cell;
	 if(id=="EmptySlots") {
	    return 0;
	 }
	 var tbody = document.getElementById(id).getElementsByTagName("tbody")[0];
	 var row = document.createElement("TR");
	 row.id = trId;
	 row.style.display = 'none';
	 cell = document.createElement("TD");
	 cell.colSpan = mergeNum;
	 cell.innerHTML = '<div id="' + divId + '"><div>';
	 row.appendChild(cell);
	 tbody.appendChild(row);
}

/**
 * Appends a table row to a table, making the first column bold; intended for Name-Value types of tables.
 * @param {string} id The name of the table to be appended.
 * @param {string[]} arrValues Array of values containing all of the row data.
 */ 
function appendRowFirstColumnBold(id, arrValues)
{
 var cell;
 var tbody = document.getElementById(id).getElementsByTagName("tbody")[0];
 var row = document.createElement("TR");
 var i;
 for (i = 0; i < arrValues.length; i++)
 {
   cell = document.createElement("TD");
	 if (i == 0)
	 {
	   cell.style.fontWeight = "bold";
	 }
	 cell.innerHTML = arrValues[i];
	 row.appendChild(cell);
 }
 tbody.appendChild(row);
}

/**
 * Creates the framework of an HTML tree using DOM calls;
 * @param {string} id The name of the tree.
 * @param {string[]} arrayTitle Array of title parameters for the tree.
 */

function createTree(id,arrayTitle)
{
	var pageBody = document.getElementsByTagName("body")[0];

	/* Tree Expansion Division */
	var divOpenClose = document.createElement("div");
	divOpenClose.className = "treeOpen";

	/* Tree Control & Disclosure Division */
	var divTreeControl = document.createElement("div");
	divTreeControl.className = "treeControl";
	var divTreeDisclosure = document.createElement("div");
	divTreeDisclosure.className = "treeDisclosure";
	divTreeControl.appendChild(divTreeDisclosure);

	/* Tree Title division */
	var divTreeTitle = document.createElement("div");
	divTreeTitle.className = "treeTitle";
	if (arrayTitle.href == "none")
	{
		var titleText = document.createTextNode(arrayTitle.titleText);
		divTreeTitle.appendChild(titleText);
	}
	else
	{
		var linkTreeTitle = document.createElement("a");
		linkTreeTitle.setAttribute("href",arrayTitle.href);
		linkTreeTitle.className=arrayTitle.linkClassName;
		linkTreeTitle.setAttribute("target",arrayTitle.target);
		var titleText = document.createTextNode(arrayTitle.titleText);
		linkTreeTitle.appendChild(titleText);
		divTreeTitle.appendChild(linkTreeTitle);
	}
			
		
	/* Tree Contents Division */	
	var divTreeContents = document.createElement("div");
	divTreeContents.className="treeContents";

	divOpenClose.appendChild(divTreeControl);
	divOpenClose.appendChild(divTreeTitle);
	divOpenClose.appendChild(divTreeContents);
	divTreeContents.setAttribute("id",id);
	pageBody.appendChild(divOpenClose);

}

/**
 * Appends a tree leaf to a tree.
 * @param {string} id The name of the tree to be appended.
 * @param {string[]} arrayLink Array of values containing all of the leaf data.
 */ 
function appendTreeLeaf(id,arrayLink)
{
	var divTreeContents= document.getElementById(id);
	var divWrapper = document.createElement("div");
	divWrapper.className = "leafWrapper";
	var divTreeLeaf = document.createElement("div");
	divTreeLeaf.className = "leaf";
	if (arrayLink.href == "none")
	{
	  currenttext = document.createTextNode(arrayLink.leafTitle);
	  divTreeLeaf.appendChild(currenttext);
	}
	else
	{
	  linkTreeLink = document.createElement("a");
	  linkTreeLink.setAttribute("href",arrayLink.href);
	  linkTreeLink.setAttribute("target",arrayLink.target);
	  currenttext = document.createTextNode(arrayLink.leafTitle);
	  linkTreeLink.appendChild(currenttext);
	  divTreeLeaf.appendChild(linkTreeLink);
	}
	divWrapper.appendChild(divTreeLeaf); 
	divTreeContents.appendChild(divWrapper);
}

/**
 * Creates the framework of an HTML tree using DOM calls,including
 * and image representing status.
 * @param {string} id The name of the tree.
 * @param {object[]} arrayTitle Array of title parameters for the tree.
 * @param {string} imgpath Path of the image representing status.
 *
 */

function createTreewithimage(id,arrayTitle,imgpath)
{
	var pageBody = document.getElementsByTagName("body")[0];
	
	/* Tree Expansion Division */
	var divOpenClose = document.createElement("div");
	divOpenClose.className = "treeOpen";
	
	/* Tree Control & Disclosure Division */
	var divTreeControl = document.createElement("div");
	divTreeControl.className = "treeControl";
		var divTreeDisclosure = document.createElement("div");
		divTreeDisclosure.className = "treeDisclosure";
		divTreeControl.appendChild(divTreeDisclosure);
	
	/* Tree Title division */
	var divTreeTitle = document.createElement("div");
	divTreeTitle.className = "treeTitle";
		var linkTreeTitle = document.createElement("a");
		linkTreeTitle.setAttribute("href",arrayTitle.href);
		linkTreeTitle.className=arrayTitle.linkClassName;
		linkTreeTitle.setAttribute("target",arrayTitle.target);
			var titleimg = document.createElement("img");
			titleimg.setAttribute("src",imgpath[0]);
			titleimg.setAttribute("alt",imgpath[1]);
			var titleText = document.createTextNode(arrayTitle.titleText);
			divTreeTitle.appendChild(titleimg);
			linkTreeTitle.appendChild(titleText);
		divTreeTitle.appendChild(linkTreeTitle);
		
	/* Tree Contents Division */	
	var divTreeContents = document.createElement("div");
	divTreeContents.className="treeContents";
	
	divOpenClose.appendChild(divTreeControl);
	divOpenClose.appendChild(divTreeTitle);
	divOpenClose.appendChild(divTreeContents);
	divTreeContents.setAttribute("id",id);
	pageBody.appendChild(divOpenClose);
   
}

/**
 * Appends a tree leaf to a tree.
 * @param {string} id The name of the tree to be appended.
 * @param {string[]} arrayLink Array of values containing all of the leaf data.
 * @param {string} imgpath Path of the image representing status.
 */ 
function appendTreeLeafwithimage(id,arrayLink,imgpath)
{
	var divTreeContents= document.getElementById(id);
	var divWrapper = document.createElement("div");
	divWrapper.className = "leafWrapper";
	var divTreeLeaf = document.createElement("div");
	divTreeLeaf.className = "leaf";
	if (arrayLink.href == "none")
	{
	  var titleimg = document.createElement("img");
	  titleimg.setAttribute("src",imgpath[0]);
	  titleimg.setAttribute("alt",imgpath[1]);
	  divTreeLeaf.appendChild(titleimg);

	  currenttext = document.createTextNode(arrayLink.leafTitle);
	  divTreeLeaf.appendChild(currenttext);	  
	}
	else
	{
	  linkTreeLink = document.createElement("a");
	  linkTreeLink.setAttribute("href",arrayLink.href);
	  linkTreeLink.setAttribute("target",arrayLink.target);
	  var titleimg = document.createElement("img");
	  titleimg.setAttribute("src",imgpath[0]);
	  titleimg.setAttribute("alt",imgpath[1]);
	  currenttext = document.createTextNode(arrayLink.leafTitle);
	  divTreeLeaf.appendChild(titleimg);
	  linkTreeLink.appendChild(currenttext);
      divTreeLeaf.appendChild(linkTreeLink);
	}
    divWrapper.appendChild(divTreeLeaf); 
    divTreeContents.appendChild(divWrapper);
}

  /**
  * Create a large-sized masthead
	* @param {string} imgLogo A string representing the name and path of the HP masthead image
	* @param {string} title Title that will appear in the masthead
	* @param {string} picMasthead A string representing the name and path of the picture that will appear on the masthead
	* @param {string} helpurl Path to help page
	*/
 function Largemasthead(imgLogo,title,picMasthead,helpurl)
 {
	document.write('<table border="0" cellpadding="0" cellspacing="0" width="100%" class="applicationMastheadLarge">');
	document.write('<tr>');
	document.write('<td class="mastheadIcon" width="42"><img src='+imgLogo+' width="42" height="26" border="0" alt="HP"></td>');
	document.write('<td class="mastheadTitle">');
	document.write('<h1>'+title+'</h1></td>');
	document.write('<td width="307"><div class="mastheadPhoto" style="padding-right:0px;"><img src="'+picMasthead+'" width="307" height="57" border="0" alt=""></div></td>');
	document.write('<td class="mastheadLinks" style="padding:5px 16px;"><br><br>');
	document.write('<a href="'+helpurl+'" target="helpwindow">Help</a>');
	document.write('</td>');
	document.write('</tr>');
	document.write('</table>');
}

 /**
  * Create a small-sized masthead
	* @param {string} imgLogo A string representing the name and path of the HP masthead image
	* @param {string} title Title that will appear in the masthead
	* @param {string} picMasthead A string representing the name and path of the picture that will appear on the masthead
	* @param {string} helpurl Path to help page
	*/
function Smallmasthead(imgLogo,title,picMasthead,helpurl)
{
	document.write('<table border="0" cellpadding="0" cellspacing="0" width="100%" class="applicationMastheadSmall">');
	document.write('<tr>');
	document.write('<td class="mastheadIcon" width="30"><img src='+imgLogo+' width="30" height="19" border="0" alt="HP"></td>');
	document.write('<td class="mastheadTitle"><h1>'+title+'</h1></td>');
	document.write('<td width="307"><div class="mastheadPhoto"><img src="'+picMasthead+'" width="307" height="39" border="0" alt=""></div></td>');
	document.write('<td class="mastheadLinks" style="padding:5px 16px;"><br>');
	document.write('<a href="'+helpurl+'" target="helpwindow">Help</a>');
	document.write('</td>');
	document.write('</tr>');
	document.write('</table>');
}


/**
 * Creates the framework of an HTML Ordered List using DOM calls; 
 * @param {string} id The name of the Ordered List.
 */

function CreateOrderedList(id)
{
	var pageBody = document.getElementsByTagName("body")[0];
	var orderedList = document.createElement("ol");
	orderedList.setAttribute("id",id);
	pageBody.appendChild(orderedList);	
}

/**
 * Creates the framework of an HTML Unordered List using DOM calls; 
 * @param {string} id The name of the Unordered List.
 */

function CreateUnorderedList(id)
{
	var pageBody = document.getElementsByTagName("body")[0];
	var unorderedList = document.createElement("ul");
	unorderedList.setAttribute("id",id);
	pageBody.appendChild(unorderedList);	
}

/**
 * Append listitems to a list.
 * @param {string} id The name of the list to be appended.
 * @param {string[]} arrayList Array of values containing all of the listitem data.
 */ 
function appendListItem(id,arrayList)
{
	var list;
	var listItem = document.getElementById(id);
	for (var i = 0; i < arrayList.length; i++) 
	{
		list = document.createElement("li");
		var linklistTitle = document.createElement("a");
		linklistTitle.setAttribute("href",arrayList[i].href); 
		var listTitle = document.createTextNode(arrayList[i].Title);
		linklistTitle.appendChild(listTitle);
		list.appendChild(linklistTitle);
		listItem.appendChild(list);
	}
}

/**
 * Append ordered list to a list.
 * @param {string} id The name of the list to be appended.
 * @param {string} subid The name of the new orderedlist.
 */ 	 
function appendOrderedList(id,subid)
{
	var list = document.getElementById(id);
	subList = document.createElement("ol");
	subList.setAttribute("id",subid);
	list.appendChild(subList);
}

/**
 * Append unordered list to a list.
 * @param {string} id The name of the list to be appended.
 * @param {string} subid The name of the new unorderedlist.
 */ 	
function appendUnorderedList(id,subid)
{
	var list = document.getElementById(id);
	subList = document.createElement("ul");
	subList.setAttribute("id",subid);
	list.appendChild(subList);
}

/**
 * Trims white space from a string
 */
String.prototype.trim=function()
{
  return this.replace(/^\s*|\s*$/g,'');
}

/**
 * Convert a decimal value to a hexadecimal value
 * @param {int} d Decimal value
 * @return Hexadecimal value
 * @type string
 */
function decimalToHex(d) {
  var hD="0123456789ABCDEF";
  var h = hD.substr(d&15,1);
  while(d>15) {d>>=4;h=hD.substr(d&15,1)+h;}
  return h;
}

/**
 * Add leading zeros; used to fill in hex values.
 * @param {string} n String to have leading zeros prepended.
 * @param {int} totalDigits Total number of digits.
 * @return String with leading zeros
 * @type string
 */
function padLeadingZeros(n, totalDigits)
{
        n = n.toString(); 
        var pd = ''; 
        if (totalDigits > n.length) 
        { 
            for (var i=0; i < (totalDigits-n.length); i++) 
            { 
                pd += '0'; 
            } 
        } 
        return pd + n.toString(); 
}

/**
 * Name value table data.  This function will check that the data exists
 * and only display when it exists.
 * @param {string} name String representing the name of the property
 * @param {string} value String that contains the WMI property that contains the value
 * @param {string} table String representing the table to append to
 */
function displayNameValuePair(name, value, table)
{
  if (value == 0)
  {
	var arrValues = new Array();
	arrValues[0] = name;
	arrValues[1] = value;
	appendRowFirstColumnBold(table, arrValues);
  }
  else if(value)
  {
	var arrValues = new Array();
	arrValues[0] = name;
	arrValues[1] = value;
	appendRowFirstColumnBold(table, arrValues);
  }
}


/**

* Returns the status 

**/

function StatusImage(status, imageType)
{
	var arrTmp = new Array();
		if (imageType == "redundancy")
		{
		  arrTmp = getRedundancyImagePath(status);
		}
		else if (imageType == "opstat")
		{
		  arrTmp = getOpstatImagePath(status);
		}
		return arrTmp;
}


/** 

* create data table and add into the given container.

**/
function createSecondaryTitle(mainid,status, imageType,sectitle,id,divid)
{
	  	var mymaindiv = document.getElementById(mainid);
		var arrTmp = new Array();
		if (imageType == "redundancy")
		{
		  arrTmp = getRedundancyImagePath(status);
		}
		else if (imageType == "opstat")
		{
		  arrTmp = getOpstatImagePath(status);
		}

		var mycap = document.createElement("h3");
		mycap.className = "subTitle";
		mycap.setAttribute("id",id);
		var mydiv = document.createElement("div");
		mydiv.className = "subTitleBottomEdge";
		mydiv.setAttribute("id",divid);
		var myimage = document.createElement("img");
		myimage.src = arrTmp[0];
		myimage.alt = arrTmp[1];
		currenttext = document.createTextNode(" "+sectitle);
		mycap.appendChild(myimage);
		mycap.appendChild(currenttext);
		mymaindiv.appendChild(mycap);
		mymaindiv.appendChild(mydiv);
}

/** 

* create data table and add into the given container.

**/
function createTableSpecialRedundancySets1(mainid,id, arrStatus, arrHeadings, arrWidths)
{
	if (arrHeadings.length != arrWidths.length)
	{
	  createTable(id, arrHeadings);
		return 0;
	}

  var mybody = document.getElementById(mainid);
	// creates <table> and <tbody> elements
  mytable     = document.createElement("table");
  mytablebody = document.createElement("tbody");
	
	  // creating all cells
    // creates a <tr> element
    mycurrent_row = document.createElement("tr");
		mycurrent_row.className="captionRow";
		
		mycolgroup = document.createElement("colgroup");
		for (var i=0; i<arrHeadings.length; i++)
		{	
			mycol = document.createElement("col");
			w = arrWidths[i] + "%";
			mycol.width = w;
			mycolgroup.appendChild(mycol);
		}
		mytable.appendChild(mycolgroup);
		
		for (var i=0; i<arrHeadings.length; i++)
		{
			// create heading
			if (i > 0)
			{
			   var img = document.createElement("img");
			   var arrTmp = new Array();
			   arrTmp = getRedundancyImagePath(arrStatus[i]);
			   img.src = arrTmp[0];
			   img.alt = arrTmp[1];
			}
			mycurrent_cell = document.createElement("th");
			if (i > 0)
			{
				mycurrent_cell.appendChild(img);
				currenttext = document.createTextNode(" " + arrHeadings[i]);
				mycurrent_cell.appendChild(currenttext);
			}
			else
			{
			   currenttext = document.createTextNode(arrHeadings[i]);
			   mycurrent_cell.appendChild(currenttext);
			}
			mycurrent_row.appendChild(mycurrent_cell);
		}
					
		// appends the row <tr> into <tbody>
    mytablebody.appendChild(mycurrent_row);
						
		// appends <tbody> into <table>
    mytable.appendChild(mytablebody);
    // appends <table> into <body>
    mybody.appendChild(mytable);
    // set attributes
    mytable.setAttribute("id",id);
		mytable.setAttribute("border","0");
		mytable.setAttribute("cellPadding","0");
		mytable.setAttribute("cellSpacing","0");
		mytable.className="dataTable";
}

/** 

* create tree and add into the given container.

**/
function createTree1(id,arrayTitle,tagId)
{
	var pageBody = document.getElementById(tagId);
	/* Tree Expansion Division */
	var divOpenClose = document.createElement("div");
	divOpenClose.className = "treeOpen";
	
	/* Tree Control & Disclosure Division */
	var divTreeControl = document.createElement("div");
	divTreeControl.className = "treeControl";
		var divTreeDisclosure = document.createElement("div");
		divTreeDisclosure.className = "treeDisclosure";
		divTreeControl.appendChild(divTreeDisclosure);
	
	/* Tree Title division */
	var divTreeTitle = document.createElement("div");
	divTreeTitle.className = "treeTitle";
		var linkTreeTitle = document.createElement("a");
		linkTreeTitle.setAttribute("href",arrayTitle.href);
		linkTreeTitle.className=arrayTitle.linkClassName;
		linkTreeTitle.setAttribute("target",arrayTitle.target);
			var titleText = document.createTextNode(arrayTitle.titleText);
			linkTreeTitle.appendChild(titleText);
		divTreeTitle.appendChild(linkTreeTitle);
		
	/* Tree Contents Division */	
	var divTreeContents = document.createElement("div");
	divTreeContents.className="treeContents";
	var brk = document.createElement("br");
	divOpenClose.appendChild(divTreeControl);
	divOpenClose.appendChild(divTreeTitle);
	divOpenClose.appendChild(divTreeContents);
		divOpenClose.appendChild(brk);
	divTreeContents.setAttribute("id",id);
	pageBody.appendChild(divOpenClose);
	
   
}

/**
 * Yangxu
 * This function toggles the grids and configuration tables
 **/

function showHide(id)
{
	var divID = "#"+id;	
	if($(divID).is(":hidden")) {
		addCookie('state_' + id , 'visible', 1);
	}
	else{
		addCookie('state_' + id, 'hidden', 1);
	}
	$(divID).slideToggle("fast");  
	
}

function addCookie(name,value,expiresHours){ 
	var cookieString=name+"="+escape(value); 
	if(expiresHours>0){ 
		var date=new Date(); 
		date.setTime(date.getTime()+expiresHours*3600*1000); 
		cookieString=cookieString+"; expires="+date.toGMTString(); 
	} 
	document.cookie=cookieString; 
	var strCookie=document.cookie; 
	var arrCookie=strCookie.split("; "); 
}

function getCookie(name){ 
	var strCookie=document.cookie; 
	var arrCookie=strCookie.split("; "); 
	for(var i=0;i<arrCookie.length;i++){ 
		var arr=arrCookie[i].split("="); 
		if(arr[0]==name)
			return arr[1]; 
	} 
	return ""; 
}